.TH CORE 3X
.SH NAME
CoreClass \- the Xt Intrinsics core widget meta class
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.SH CLASSES
All widgets are built from the Core class.
.SH DESCRIPTION
The Core class is an Xt Intrinsics meta class.  It is never
instantiated as a widget.  Its sole purpose is as a
supporting superclass for other widget classes.  It provides
resources required by all widgets: x y location, width,
height, window border width, and so on.
.SH "NEW RESOURCES"
Core defines a set of resource types used by the programmer
to specify the data for widgets which are subclasses of
Core.
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.TP 5
XtNancestorSensitive
.br
This argument specifies whether the immediate parent of
the widget will receive input events.  Use the function
XtSetSensitive if you are changing the argument to
.IP "" 5
preserve data integrity (see XtNsensitive below).
.TP 5
XtNx
This argument contains the x-coordinate of the widget's
upper left hand corner (excluding the border) in
relation to its parent widget.  Programs should not
change this argument directly, but use geometry manager
requests instead in order to ensure proper
relationships with other widgets are maintained.
.TP 5
XtNy
This argument contains the y-coordinate of the widget's
upper left hand corner (excluding the border) in
relation to its parent widget.  Programs should not
change this argument directly, but use geometry manager
requests instead in order to ensure proper
relationships with other widgets are maintained.
.TP 5
XtNwidth
.br
This argument contains the width of the widget's window
in pixels, not including the border area. Programs
should not change this argument directly, but use
geometry manager requests instead in order to ensure
proper relationships with other widgets are maintained.
.TP 5
XtNheight
.br
This argument contains the height of the widget's
window in pixels, not including the border area.
Programs should not change this argument directly, but
use geometry manager requests instead in order to
ensure proper relationships with other widgets are
maintained.
.TP 5
XtNdepth
.br
Determines how many bits should be used for each pixel
in the widget's window.  Programs should not change or
set this, it will be set by the Xt Intrinsics when the
widget is created.
.TP 5
XtNbackground
.br
This argument specifies the background color for the
widget.
.TP 5
XtNbackgroundPixmap
.br
The application can specify a pixmap to be used for
tiling the background. The first tile is place at the
upper left hand corner of the widget's window.
.TP 5
XtNborderWidth
.br
This argument sets the width of the border that
surrounds the widget's window on all four sides.  The
width is specified in pixels.  A width of zero means no
border will show.
.TP 5
XtNborderColor
.br
This argument specifies the color of the border.
.TP 5
XtNborderPixmap
.br
The application can specify a pixmap to be used for
tiling the border. The first tile is place at the upper
left hand corner of the border.
.TP 5
XtNsensitive
.br
This argument determines whether a widget will receive
input events.  If a widget is sensitive, the Xt
Intrinsic's Event Manager will dispatch to the widget
all keyboard, mouse button, motion, window enter/leave,
and focus events.  Insensitive widgets do not receive
these events.  Use the function XtSetSensitive if you
are changing the sensitivity argument.  That way you
ensure that if a parent widget has XtNsensitive set to
FALSE, the ancestor-sensitive flag of all its children
will be appropriately set.
.TP 5
XtNmappedWhenManaged
.br
If set to TRUE, the widget will be mapped (made
visible) as soon as it is both realized and managed.
.br
If set to FALSE, the client is responsible for mapping
and unmapping the widget.  If the value is changed from
TRUE to FALSE after the widget has been realized and
managed, the widget is unmapped.
.TP 5
XtNdestroyCallback
.br
This is a pointer to a callback list containing
routines to be called when the widget is destroyed.
.TP 5
XtNtranslations
.br
This is a pointer to a translations list.
.SH "INHERITED RESOURCES"
The Core class is the root class.  It inherits no resources.
.SH TRANSLATIONS
None
.SH ACTIONS
None
.SH ORIGIN
MIT.
.SH "SEE ALSO"
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
